def load_dic(path):
    """
    Loads a list of words from a specified file.

    Parameters:
    - path (str): The path to the file containing the list of words, one per line.

    Returns:
    - list: A list of words extracted from the file.

    Notes:
    - The function assumes that the file encoding is UTF-8.
    - It also assumes that each word is on a separate line in the file.

    Example:
    >>> load_dic("data/sample.txt")
    ['aalenien', 'aalenienne', 'aaleniennes']
    """

    lst = []
    with open(path, "r", encoding="UTF-8") as f:
        for row in f:
            print(row)
            lst.append(row.strip().lower())
            break
    return lst


def french_scrabble_score(word):
    # Point values for each letter in French Scrabble
    letter_values = {
        'a': 1, 'e': 1, 'i': 1, 'o': 1, 'u': 1, 'l': 1, 'n': 1, 'r': 1, 's': 1,
        't': 1,
        'd': 2, 'g': 2, 'm': 2,
        'b': 3, 'c': 3, 'p': 3,
        'f': 4, 'h': 4, 'v': 4,
        'j': 8, 'q': 8,
        'k': 10, 'w': 10, 'x': 10, 'y': 10,
        'z': 10
    }
    dico = load_dic("data/dico.txt")
    # Check if the word is in the dictionary
    if word not in dico:
        return -1

    # Check if the word contains any accents
    for char in word:
        if char not in letter_values:
            raise ValueError(
                f"Letter '{char}' not handled by the function.")

    # Calculate the score
    score = 0
    # Convert the word to lowercase to ensure matching
    for letter in word.lower():
        score += letter_values.get(letter, 0)

    return score
