from typing import Any


def add(x: Any, y: Any) -> Any:
    """
    Doctest:
    >>> add(3,-2)
    2
    >>> add(1/3, 1/2)
    0.8333333333333333
    >>> add("doc", "strings")
    'docstrings'
    """
    return x + y


def fibo(num: int) -> int:
    """
    Calculate the Fibonacci number.
    Parameters:
    - num (int): The position of the desired Fibonacci number (0-based index).
    Returns:
    - int: The Fibonacci number at the given position.

    Doctest:
    >>> fibo(0)
    0
    >>> fibo(10)
    55
    >>> fibo("nine")
    Traceback (most recent call last):
    ...
    TypeError: num should be of type int.
    >>> fibo(0.2)
    Traceback (most recent call last):
    ...
    TypeError: num should be of type int.
    >>> fibo(-1)
    Traceback (most recent call last):
    ...
    ValueError: num should be positive.
    """
    if not isinstance(num, int):
        raise TypeError("num should be of type int.")
    elif num < 0:
        raise ValueError("num should be positive.")
    else:
        res = [0, 1]
        for _ in range(2, num + 1):
            res.append((res[-1] + res[-2]))
        return res[num]


def factorial(n):
    """Return the factorial of n, an exact integer >= 0.

    >>> [factorial(n) for n in range(6)]
    [1, 1, 2, 6, 24, 120]
    >>> factorial(30)
    265252859812191058636308480000000
    >>> factorial(-1)
    Traceback (most recent call last):
        ...
    ValueError: n must be >= 0

    Factorials of floats are OK, but the float must be an exact integer:
    >>> factorial(30.1)
    Traceback (most recent call last):
        ...
    ValueError: n must be exact integer
    >>> factorial(30.0)
    265252859812191058636308480000000

    It must also not be ridiculously large:
    >>> factorial(1e100)
    Traceback (most recent call last):
        ...
    OverflowError: n too large
    """

    import math
    if not n >= 0:
        raise ValueError("n must be >= 0")
    if math.floor(n) != n:
        raise ValueError("n must be exact integer")
    if n + 1 == n:  # catch a value like 1e300
        raise OverflowError("n too large")
    result = 1
    factor = 2
    while factor <= n:
        result *= factor
        factor += 1
    return result


def count_vowels(s: str) -> int:
    vowels = "aeiouyAEIOUY"
    count = sum(1 for char in s if char in vowels)
    return count


if __name__ == '__main__':
    import doctest
    doctest.testmod()
